# pympernel

> Short blurb about what your product does.

[![PyPI version](https://badge.fury.io/py/pympernel.svg)](https://badge.fury.io/py/pympernel)
[![readthedocs][readthedocs-image]][readthedocs-url]
[![pre-commit][pre-commit-image]][pre-commit-url]
[![Imports: isort][isort-image]][isort-url]
[![Code style: black][black-image]][black-url]
[![Checked with mypy][mypy-image]][mypy-url]
[![security: bandit][bandit-image]][bandit-url]
[![Commitizen friendly][commitizen-image]][commitizen-url]
[![licence: mit][mit-license-image]][mit-license-url]

One to two paragraph statement about your product and what it does.

![](assets/header.png)

## Installation

OS X & Linux:

```sh
pip3 install pympernel
```

Windows:

```sh
pip install pympernel
```

## Usage example

A few motivating and useful examples of how your product can be used. Spice this up with code blocks and potentially more screenshots.

_For more examples and usage, please refer to the [Wiki][wiki]._

## Development setup

Describe how to install all development dependencies and how to run an automated test-suite of some kind. Potentially do this for multiple platforms.

```sh
pip install --editable pympernel
```

## Documentation

[**Read the Docs**](https://pympernel.readthedocs.io/en/latest/)

## Meta

[![](assets/linkedin.png)](https://linkedin.com/in/stephen-k-3a4644210)
[![](assets/github.png)](https://github.com/Stephen-RA-King/Stephen-RA-King)
[![](assets/pypi.png)](https://pypi.org/project/pympernel/)
[![](assets/www.png)](https://www.Stephen-RA-King)
[![](assets/email.png)](mailto:stephen.ra.king@gmail.com)

Stephen R A King : stephen.ra.king@gmail.com

Distributed under the MIT License. See `LICENSE` for more information.

[https://github.com/Stephen-RA-King/pympernel](https://github.com/Stephen-RA-King/pympernel)

<!-- Markdown link & img dfn's -->

[commitizen-image]: https://img.shields.io/badge/commitizen-friendly-brightgreen.svg
[commitizen-url]: http://commitizen.github.io/cz-cli/
[readthedocs-image]: https://readthedocs.org/projects/pympernel/badge/?version=latest
[readthedocs-url]: https://pympernel.readthedocs.io/en/latest/?badge=latest
[pre-commit-image]: https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white
[pre-commit-url]: https://github.com/pre-commit/pre-commit
[isort-image]: https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336
[isort-url]: https://pycqa.github.io/isort/
[black-image]: https://img.shields.io/badge/code%20style-black-000000.svg
[black-url]: https://github.com/psf/black
[bandit-image]: https://img.shields.io/badge/security-bandit-yellow.svg
[bandit-url]: https://github.com/PyCQA/bandit
[mypy-image]: http://www.mypy-lang.org/static/mypy_badge.svg
[mypy-url]: http://mypy-lang.org/
[mit-license-image]: https://img.shields.io/badge/license-MIT-blue
[mit-license-url]: https://choosealicense.com/licenses/mit/
[wiki]: https://github.com/Stephen-RA-King/pympernel/wiki
